[dpdk-dev] [PATCH v3 13/17] examples/multi_process: replace references to master/slave

Stephen Hemminger stephen at networkplumber.org
Tue Sep 15 17:11:10 CEST 2020


Replace master with main and slave with worker.
Fix the wording in comments.

Acked-by: Anatoly Burakov <anatoly.burakov at intel.com>
Signed-off-by: Stephen Hemminger <stephen at networkplumber.org>
---
 .../multi_process/client_server_mp/mp_server/main.c    | 10 +++++-----
 examples/multi_process/simple_mp/main.c                |  4 ++--
 examples/multi_process/symmetric_mp/main.c             |  2 +-
 3 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/examples/multi_process/simple_mp/main.c b/examples/multi_process/simple_mp/main.c
index fc79528462e9..86b7d244a91f 100644
--- a/examples/multi_process/simple_mp/main.c
+++ b/examples/multi_process/simple_mp/main.c
@@ -108,12 +108,12 @@ main(int argc, char **argv)
 
 	RTE_LOG(INFO, APP, "Finished Process Init.\n");
 
-	/* call lcore_recv() on every slave lcore */
+	/* call lcore_recv() on every worker lcore */
 	RTE_LCORE_FOREACH_SLAVE(lcore_id) {
 		rte_eal_remote_launch(lcore_recv, NULL, lcore_id);
 	}
 
-	/* call cmd prompt on master lcore */
+	/* call cmd prompt on main lcore */
 	struct cmdline *cl = cmdline_stdin_new(simple_mp_ctx, "\nsimple_mp > ");
 	if (cl == NULL)
 		rte_exit(EXIT_FAILURE, "Cannot create cmdline instance\n");
diff --git a/examples/multi_process/symmetric_mp/main.c b/examples/multi_process/symmetric_mp/main.c
index 9a16e198cbf4..95ef436c56eb 100644
--- a/examples/multi_process/symmetric_mp/main.c
+++ b/examples/multi_process/symmetric_mp/main.c
@@ -473,7 +473,7 @@ main(int argc, char **argv)
 
 	RTE_LOG(INFO, APP, "Finished Process Init.\n");
 
-	rte_eal_mp_remote_launch(lcore_main, NULL, CALL_MASTER);
+	rte_eal_mp_remote_launch(lcore_main, NULL, CALL_MAIN);
 
 	return 0;
 }
diff --git a/examples/multi_process/client_server_mp/mp_server/main.c b/examples/multi_process/client_server_mp/mp_server/main.c
index 280dab867281..ec7f6b11f30e 100644
--- a/examples/multi_process/client_server_mp/mp_server/main.c
+++ b/examples/multi_process/client_server_mp/mp_server/main.c
@@ -84,7 +84,7 @@ get_printable_mac_addr(uint16_t port)
 /*
  * This function displays the recorded statistics for each port
  * and for each client. It uses ANSI terminal codes to clear
- * screen when called. It is called from a single non-master
+ * screen when called. It is called from a single worker
  * thread in the server process, when the process is run with more
  * than one lcore enabled.
  */
@@ -146,7 +146,7 @@ do_stats_display(void)
 }
 
 /*
- * The function called from each non-master lcore used by the process.
+ * The function called from each worker lcore used by the process.
  * The test_and_set function is used to randomly pick a single lcore on which
  * the code to display the statistics will run. Otherwise, the code just
  * repeatedly sleeps.
@@ -244,7 +244,7 @@ process_packets(uint32_t port_num __rte_unused,
 }
 
 /*
  * Function called by the master lcore of the DPDK process.
  */
 static void
 do_packet_forwarding(void)
@@ -297,8 +297,8 @@ main(int argc, char *argv[])
 	/* clear statistics */
 	clear_stats();
 
-	/* put all other cores to sleep bar master */
-	rte_eal_mp_remote_launch(sleep_lcore, NULL, SKIP_MASTER);
+	/* put all other cores to sleep except main */
+	rte_eal_mp_remote_launch(sleep_lcore, NULL, SKIP_MAIN);
 
 	do_packet_forwarding();
 	return 0;
@@ -244,7 +244,7 @@ process_packets(uint32_t port_num __rte_unused,
 
 /*
- * Function called by the master lcore of the DPDK process.
+ * Function called by the main lcore of the DPDK process.
  */
 static void
-- 
2.27.0



More information about the dev mailing list